#!/bin/sh

## live-build(7) - System Build Scripts
## Copyright (C) 2006-2011 Daniel Baumann <daniel@debian.org>
##
## live-build comes with ABSOLUTELY NO WARRANTY; for details see COPYING.
## This is free software, and you are welcome to redistribute it
## under certain conditions; see COPYING for details.


# Debian releases
RELEASE_lenny="5.0.6"
RELEASE_squeeze="6.0.0"
RELEASE_wheezy="7"
RELEASE_sid="unstable"

# Ubuntu releases
RELEASE_dapper="6.06" # LTS
RELEASE_hardy="8.04" # LTS
RELEASE_intrepid="8.10"
RELEASE_jaunty="9.04"
RELEASE_karmic="9.10"
RELEASE_lucid="10.04" # LTS
RELEASE_maverick="10.10"
RELEASE_natty="11.04"
